@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: collect.py 1046 2007-01-05 01:18:32Z pronovic $
+# Revision : $Id: collect.py 1136 2007-02-23 05:25:10Z pronovic $
 # Purpose  : Implements the standard 'collect' action.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -56,6 +56,7 @@ import pickle
 from CedarBackup2.filesystem import BackupFileList
 from CedarBackup2.util import isStartOfWeek, changeOwnership, displayBytes, buildNormalizedPath
 from CedarBackup2.actions.constants import DIGEST_EXTENSION, COLLECT_INDICATOR
+from CedarBackup2.actions.util import writeIndicatorFile
 
 
 ########################################################################
@@ -97,6 +98,9 @@ def executeCollect(configPath, options, config):
    logger.debug("Executing collect action.")
    if config.options is None or config.collect is None:
       raise ValueError("Collect configuration is not properly filled in.")
+   if ((config.collect.collectFiles is None or len(config.collect.collectFiles) < 1) and
+       (config.collect.collectDirs is None or len(config.collect.collectDirs) < 1)):
+      raise ValueError("There must be at least one collect file or collect directory.")
    fullBackup = options.full
    logger.debug("Full backup flag is [%s]" % fullBackup)
    todayIsStart = isStartOfWeek(config.options.startingDay)
@@ -133,7 +137,8 @@ def executeCollect(configPath, options, config):
          else:
             logger.debug("Directory will not be backed up, per collect mode.")
          logger.info("Completed collecting directory [%s]" % collectDir.absolutePath)
-   _writeCollectIndicator(config)
+   writeIndicatorFile(config.collect.targetDir, COLLECT_INDICATOR, 
+                      config.options.backupUser, config.options.backupGroup)
    logger.info("Executed the 'collect' action successfully.")
 
 
@@ -315,24 +320,6 @@ def _writeDigest(config, digest, digestPath):
       logger.error("Failed to write digest [%s] to disk." % digestPath)
 
 
-####################################
-# _writeCollectIndicator() function
-####################################
-
-def _writeCollectIndicator(config):
-   """
-   Writes a collect indicator file into a target collect directory.
-   @param config: Config object.
-   """
-   filename = os.path.join(config.collect.targetDir, COLLECT_INDICATOR)
-   logger.debug("Writing collect indicator [%s]." % filename)
-   try:
-      open(filename, "w").write("")
-      changeOwnership(filename, config.options.backupUser, config.options.backupGroup)
-   except Exception, e:
-      logger.error("Error writing collect indicator: %s" % e)
-
-
 ########################################################################
 # Private attribute "getter" functions
 ########################################################################
