@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 1100 2007-01-31 05:16:03Z pronovic $
+# Revision : $Id: release.py 1142 2007-02-24 05:09:48Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +34,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2007"
-VERSION     = "2.10.1"
-DATE        = "30 Jan 2007"
+VERSION     = "2.12.0"
+DATE        = "23 Feb 2007"
 URL         = "http://cedar-solutions.com/software/cedar-backup"
 
