@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: dvdwriter.py 1091 2007-01-31 03:02:41Z pronovic $
+# Revision : $Id: dvdwriter.py 1115 2007-02-18 03:11:32Z pronovic $
 # Purpose  : Provides functionality related to DVD writer devices.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -243,6 +243,8 @@ class DvdWriter(object):
 
       Only these methods will be used by other Cedar Backup functionality
       that expects a compatible image writer.
+   
+      The media attribute is also assumed to be available.
 
       Unlike the C{CdWriter}, the C{DvdWriter} can only operate in terms of
       filesystem devices, not SCSI devices.  So, although the constructor
@@ -341,7 +343,8 @@ class DvdWriter(object):
    # Constructor
    ##############
 
-   def __init__(self, device, scsiId=None, driveSpeed=None, mediaType=MEDIA_DVDPLUSRW, unittest=False):
+   def __init__(self, device, scsiId=None, driveSpeed=None, 
+                mediaType=MEDIA_DVDPLUSRW, noEject=False, unittest=False):
       """
       Initializes a DVD writer object.
 
@@ -349,6 +352,12 @@ class DvdWriter(object):
       C{/dev/dvd}), the hardware id will always be set based on the device.  If
       passed in, it will be saved for reference purposes only.
 
+      We have no way to query the device to ask whether it has a tray or can be
+      safely opened and closed.  So, the C{noEject} flag is used to set these
+      values.  If C{noEject=False}, then we assume a tray exists and open/close
+      is safe.  If C{noEject=True}, then we assume that there is no tray and
+      open/close is not safe.
+
       @note: The C{unittest} parameter should never be set to C{True}
       outside of Cedar Backup code.  It is intended for use in unit testing
       Cedar Backup internals and has no other sensible purpose.
@@ -365,6 +374,9 @@ class DvdWriter(object):
       @param mediaType: Type of the media that is assumed to be in the drive.
       @type mediaType: One of the valid media type as discussed above.
 
+      @param noEject: Tells Cedar Backup that the device cannot safely be ejected
+      @type noEject: Boolean true/false
+
       @param unittest: Turns off certain validations, for use in unit testing.
       @type unittest: Boolean true/false 
 
@@ -373,14 +385,18 @@ class DvdWriter(object):
       @raise ValueError: If the drive speed is not an integer >= 1.
       """
       if scsiId is not None:
-         logger.warn("SCSI id [%s] will be ignored by DvdWriter.")
+         logger.warn("SCSI id [%s] will be ignored by DvdWriter." % scsiId)
       self._image = None  # optionally filled in by initializeImage()
       self._device = validateDevice(device, unittest)
       self._scsiId = scsiId  # not validated, because it's just for reference
       self._driveSpeed = validateDriveSpeed(driveSpeed)
       self._media = MediaDefinition(mediaType)
-      self._deviceHasTray = True   # just default it
-      self._deviceCanEject = True  # just default it
+      if noEject:
+         self._deviceHasTray = False
+         self._deviceCanEject = False
+      else:
+         self._deviceHasTray = True   # just assume 
+         self._deviceCanEject = True  # just assume 
 
 
    #############
